<?php

/** Catalan localization file for KCFinder
  * author: Xevi Fuster
  * country: Catalunya
  */

$lang = array(

    '_locale' => "ca_ES.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %e %B, %Y %H:%M",
    '_dateTimeMid' => "%a %e %b %Y %H:%M",
    '_dateTimeSmall' => "%d.%m.%Y %H:%M",

    "You don't have permissions to upload files." =>
    "No té permissos per pujar arxius.",

    "You don't have permissions to browse server." =>
    "No té permissos per visualitzar arxius.",

    "Cannot move uploaded file to target folder." =>
    "No es pot moure el fitxer pujat al directori destí",

    "Unknown error." =>
    "Error desconegut.",

    "The uploaded file exceeds {size} bytes." =>
    "La mida del fitxer excedeix la mida màxima de pujada ( {size} bytes ).",

    "The uploaded file was only partially uploaded." =>
    "El fitxer només ha estat carregat parcialment.",

    "No file was uploaded." =>
    "Cap arxiu carregat",

    "Missing a temporary folder." =>
    "Directori Temporal perdut.",

    "Failed to write file." =>
    "Error en escriure el fitxer.",

    "Denied file extension." =>
    "Extensió de fitxer no permesa.",

    "Unknown image format/encoding." =>
    "Format d'imatge desconegut.",

    "The image is too big and/or cannot be resized." =>
    "La imatge és massa gran i/o no es pot redimensionar.",

    "Cannot create {dir} folder." =>
    "No s'ha pogut crear el directori {dir}",

    "Cannot write to upload folder." =>
    "No es pot escriure al directori de càrrega de fitxers.",

    "Cannot read .htaccess" =>
    "No s'ha pogut llegir .htaccess.",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "Fitxer .htaccess incorrecte. No s'el pot reescriure!",

    "Cannot read upload folder." =>
    "No s'ha pogut llegir la carpeta de càrrega de fitxers.",

    "Cannot access or create thumbnails folder." =>
    "No s'ha pogut llegir o crear la carpeta de miniatures.",

    "Cannot access or write to upload folder." =>
    "No s'ha pogut llegir o escriure la carpeta de càrrega de fitxers.",

    "Please enter new folder name." =>
    "Si us plau, entri el nom del nou directori.",

    "Unallowable characters in folder name." =>
    "Caràcters no permesos en el nom d'una carpeta.",

    "Folder name shouldn't begins with '.'" =>
    "El nom d'un directori no hauria de començar amb punt '.'",

    "Please enter new file name." =>
    "Si us plau, introdueixi un nou nom pel fitxer ",

    "Unallowable characters in file name." =>
    "Caràcters no permesos en un nom de fitxer.",

    "File name shouldn't begins with '.'" =>
    "El nom de fitxer no hauria de començar amb punt '.'",

    "Are you sure you want to delete this file?" =>
    "Està segur que vol suprimir aquest fitxer?",

    "Are you sure you want to delete this folder and all its content?" =>
    "Està segur que vol suprimir aquest directori i el seu contingut?",

    "Inexistant or inaccessible folder." =>
    "Carpeta inexistent o inaccessible.",

    "Undefined MIME types." =>
    "Tipus MIME no definit.",

    "Fileinfo PECL extension is missing." =>
    "Fitxer PECL amb estructura incorrecta.",

    "Opening fileinfo database failed." =>
    "Error obrint el fitxer d'informació de la base de dades.",

    "You can't upload such files." =>
    "No pot carregar tants fitxers.",

    "The file '{file}' does not exist." =>
    "El fitxer '{file}' no existeix.",

    "Cannot read '{file}'." =>
    "No s'ha pogut llegir '{file}'.",

    "Cannot copy '{file}'." =>
    "No s'ha pogut copiar '{file}'.",

    "Cannot move '{file}'." =>
    "No s&#39;ha pogut moure '{file}'.",

    "Cannot delete '{file}'." =>
    "No s'ha pogut esborrar '{file}'.",

    "Click to remove from the Clipboard" =>
    "Faci click per esborrar del portapapers",

    "This file is already added to the Clipboard." =>
    "Aquest arxiu ja havia estat afegit al portapapers.",

    "Copy files here" =>
    "Copiar fitxers aquí",

    "Move files here" =>
    "Moure fitxers aquí",

    "Delete files" =>
    "Esborrar fitxers",

    "Clear the Clipboard" =>
    "Buidar el portapapers",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "Està convençut que vol esborrar tots els fitxers del portapapers?",

    "Copy {count} files" =>
    "Copiar {count} fitxers",

    "Move {count} files" =>
    "Moure {count} fitxers ",

    "Add to Clipboard" =>
    "Afegir al portapapers",

    "New folder name:" => "Nou nom del directori:",
    "New file name:" => "Nou nom del fitxer:",

    "Upload" => "Carregar",
    "Refresh" => "Refrescar",
    "Settings" => "Preferències",
    "Maximize" => "Maximitzar",
    "About" => "En quant a...",
    "files" => "Fitxers",
    "View:" => "Veure:",
    "Show:" => "Mostrar:",
    "Order by:" => "Ordenar per:",
    "Thumbnails" => "Miniatures",
    "List" => "Llista",
    "Name" => "Nom",
    "Size" => "Mida",
    "Date" => "Data",
    "Descending" => "Descendent",
    "Uploading file..." => "Carregant fitxer...",
    "Loading image..." => "Carregant imatge...",
    "Loading folders..." => "Carregant directoris...",
    "Loading files..." => "Carregant fitxers...",
    "New Subfolder..." => "Nou subdirectori...",
    "Rename..." => "Canviar el nom...",
    "Delete" => "Eliminar",
    "OK" => "OK",
    "Cancel" => "Cancel.lar",
    "Select" => "Seleccionar",
    "Select Thumbnail" => "Seleccionar miniatura",
    "View" => "Veure",
    "Download" => "Descarregar",
    "Clipboard" => "Portapapers",

    // VERSION 2 NEW LABELS

    "Cannot rename the folder." =>
    "No es pot canviar el nom del directori.",

    "Non-existing directory type." =>
    "Tipus de directori inexistent.",

    "Cannot delete the folder." =>
    "No es pot esborrar el directori.",

    "The files in the Clipboard are not readable." =>
    "Els fitxers del portapapers són illegibles.",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "{count} fitxers no es poden llegir. Vol copiar la resta?",

    "The files in the Clipboard are not movable." =>
    "Els fitxers del portapapers no es poden moure.",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "{count} fitxers del portapapers no es poden moure. Vol moure la resta?",

    "The files in the Clipboard are not removable." =>
    "Els fitxers del portapapers no es poden eliminar.",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "{count} fitxers del portapapers no poden ser eliminats. Vol eliminar la resta?",

    "The selected files are not removable." =>
    "Els fitxers seleccionats no poden ser esborrats.",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "{count} fitxers dels seleccionats no poden ser esborrats. Vol esborrar la resta?",

    "Are you sure you want to delete all selected files?" =>
    "Està segur que vol eliminar els fitxers seleccionats?",

    "Failed to delete {count} files/folders." =>
    "Error en esborrar {count} fitxers/directoris.",

    "A file or folder with that name already exists." =>
    "Ja existeix un directori o un fitxer amb aquest nom.",

    "selected files" => "Fitxers seleccionats",
    "Type" => "Tipus",
    "Select Thumbnails" => "Seleccionar miniatures",
    "Download files" => "Descarregar fitxers",
);

?>
