<?php

/** Italian localization file for KCFinder
  * author: Ivano Raffeca
  */

$lang = array(

    '_locale' => "it_IT.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %e %B, %Y %H:%M",
    '_dateTimeMid' => "%a %e %b %Y %H:%M",
    '_dateTimeSmall' => "%d.%m.%Y %H:%M",

    "You don't have permissions to upload files." =>
    "Non hai il permesso di caricare files.",

    "You don't have permissions to browse server." =>
    "Non hai il permesso di elencare i files.",

    "Cannot move uploaded file to target folder." =>
    "Non puoi spostare il file caricato nella cartella di destinazione",

    "Unknown error." =>
    "Errore sconosciuto.",

    "The uploaded file exceeds {size} bytes." =>
    "Il file caricato eccede {size} bytes.",

    "The uploaded file was only partially uploaded." =>
    "Il file è stato caricato parzialmente.",

    "No file was uploaded." =>
    "Nessun file è stato caricato",

    "Missing a temporary folder." =>
    "Cartella temporanea non trovata.",

    "Failed to write file." =>
    "Fallita la scrittura del file.",

    "Denied file extension." =>
    "Estensione del file non consentita.",

    "Unknown image format/encoding." =>
    "Sconosciuto format/encoding immagine.",

    "The image is too big and/or cannot be resized." =>
    "Immagine troppo grande e/o non può essere rimpicciolita",

    "Cannot create {dir} folder." =>
    "La cartella {dir} non può essere creata.",

    "Cannot write to upload folder." =>
    "Cartella di destinazione protetta in scrittura.",

    "Cannot read .htaccess" =>
    "Impossibile leggere il file .htaccess.",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "Il file .htaccess è corrotto. Impossibile riscriverlo!",

    "Cannot read upload folder." =>
    "Impossibile leggere il contenuto della cartella di destinazione.",

    "Cannot access or create thumbnails folder." =>
    "Impossibile creare o accedere alla cartella delle miniature.",

    "Cannot access or write to upload folder." =>
    "Impossibile accedere o scrivere nella cartella di destinazione.",

    "Please enter new folder name." =>
    "Scrivi il nome della nuova cartella.",

    "Unallowable characters in folder name." =>
    "Caratteri non permessi nel nome della cartella.",

    "Folder name shouldn't begins with '.'" =>
    "Il nome della cartella non può iniziare con'.'",

    "Please enter new file name." =>
    "Inserisci il nuovo nome del file",

    "Unallowable characters in file name." =>
    "Caratteri non permessi nel nome del file.",

    "File name shouldn't begins with '.'" =>
    "Il nome del file non può iniziare con '.'",

    "Are you sure you want to delete this file?" =>
    "Sei sicuro che vuoi cancellare questo file?",

    "Are you sure you want to delete this folder and all its content?" =>
    "Sei sicuro di voler cancellare questa cartella e il suo contenuto?",

    "Inexistant or inaccessible folder." =>
    "Tipo di cartella non esistente.",

    "Undefined MIME types." =>
    "Tipo MIME non definito.",

    "Fileinfo PECL extension is missing." =>
    "Manca estensione PECL del file.",

    "Opening fileinfo database failed." =>
    "Apertura del database delle informazioni del file fallita.",

    "You can't upload such files." =>
    "Non è possibile caricare questi files.",

    "The file '{file}' does not exist." =>
    "Il file '{file}' non esiste.",

    "Cannot read '{file}'." =>
    "Impossibile leggere il file '{file}'.",

    "Cannot copy '{file}'." =>
    "Impossibile copiare il file '{file}'.",

    "Cannot move '{file}'." =>
    "Impossibile spostare il file '{file}'.",

    "Cannot delete '{file}'." =>
    "Impossibile cancellare il file '{file}'.",

    "Click to remove from the Clipboard" =>
    "Click per rimuoverlo dalla Clipboard",

    "This file is already added to the Clipboard." =>
    "Questo file è già aggiunto alla Clipboard.",

    "Copy files here" =>
    "Copia i files qui",

    "Move files here" =>
    "Sposta i files qui",

    "Delete files" =>
    "Cancella i files",

    "Clear the Clipboard" =>
    "Pulisci la Clipboard",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "Sei sicuro che vuoi cancellare tutti i files dalla Clipboard?",

    "Copy {count} files" =>
    "Copio {count} files",

    "Move {count} files" =>
    "Sposto {count} files",

    "Add to Clipboard" =>
    "Aggiungi alla Clipboard",

    "New folder name:" => "Nuovo nome della cartella:",
    "New file name:" => "Nuovo nome del file:",

    "Upload" => "Carica",
    "Refresh" => "Aggiorna",
    "Settings" => "Preferenze",
    "Maximize" => "Massimizza",
    "About" => "Chi siamo",
    "files" => "files",
    "View:" => "Vista:",
    "Show:" => "Mostra:",
    "Order by:" => "Ordina per:",
    "Thumbnails" => "Miniature",
    "List" => "Lista",
    "Name" => "Nome",
    "Size" => "Grandezza",
    "Date" => "Data",
    "Descending" => "Discendente",
    "Uploading file..." => "Carico file...",
    "Loading image..." => "Caricamento immagine...",
    "Loading folders..." => "Caricamento cartella...",
    "Loading files..." => "caricamento files...",
    "New Subfolder..." => "Nuova sottocartella...",
    "Rename..." => "Rinomina...",
    "Delete" => "Elimina",
    "OK" => "OK",
    "Cancel" => "Cancella",
    "Select" => "Seleziona",
    "Select Thumbnail" => "Seleziona miniatura",
    "View" => "Vista",
    "Download" => "Scarica",
    "Clipboard" => "Clipboard",

    // VERSION 2 NEW LABELS

    "Cannot rename the folder." =>
    "Non è possibile rinominare la cartella.",

    "Non-existing directory type." =>
    "Il tipo di cartella non esiste.",

    "Cannot delete the folder." =>
    "Non è possibile cancellare la cartella.",

    "The files in the Clipboard are not readable." =>
    "I files nella clipboard non sono leggibili.",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "{count} files nella clipboard non sono leggibili. Copiare il resto?",

    "The files in the Clipboard are not movable." =>
    "I files nella clipboard non sono spoastabili.",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "{count} files nella clipboard non sono spoastabili. Spostare il resto?",

    "The files in the Clipboard are not removable." =>
    "files nella clipboard non si possono rimuovere.",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "{count} files nella clipboard non si possono rimuovere. Cancellare il resto?",

    "The selected files are not removable." =>
    "Il file selezionato non è rimovibile.",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "{count} i files selezionati non sono rimovibili. Cancellare il resto?",

    "Are you sure you want to delete all selected files?" =>
    "Sei sicuro che vuoi cancellare tutti i files selezionati?",

    "Failed to delete {count} files/folders." =>
    "Cancellazione fallita {count} files/cartelle.",

    "A file or folder with that name already exists." =>
    "Un file o cartella con questo nome già esiste.",

    "selected files" => "files selezionati",
    "Type" => "Tipo",
    "Select Thumbnails" => "Seleziona miniature",
    "Download files" => "Scarica files",

    // SINCE 2.34

    "Checking for new version..." => "Controllo nuova versione...",
    "Unable to connect!" => "Connessione impossibile",
    "Download version {version} now!" => "Prelevo la versione {version} adesso!",
    "KCFinder is up to date!" => "KCFinder è aggiornato!",
    "Licenses:" => "Licenze: ",
    "Attention" => "Attensione",
    "Question" => "Domanda",
    "Yes" => "Si",
    "No" => "No",

);

?>