<?php

/** Czech localization file for KCFinder
  * author: Rostislav Sivak <rsivak@rsivak.com>
  */

$lang = array(

    '_locale' => "cs_CZ.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %e.%B.%Y %H:%M",
    '_dateTimeMid' => "%a %e %b %Y %H:%M",
    '_dateTimeSmall' => "%d.%m.%Y %H:%M",

	"You don't have permissions to upload files." =>
    "Nemáte práva pro nahrávání souborů.",

    "You don't have permissions to browse server." =>
    "Nemáte práva pro prohlížení serveru.",

    "Cannot move uploaded file to target folder." =>
    "Nelze přesunout soubor do určeného adresáře.",

    "Unknown error." =>
    "Neznámá chyba.",

    "The uploaded file exceeds {size} bytes." =>
    "Nahraný soubor přesahuje {size} bytů.",

    "The uploaded file was only partially uploaded." =>
    "Nahraný soubor byl nahrán pouze částečně.",

    "No file was uploaded." =>
    "Žádný soubor nebyl nahrán na server.",

    "Missing a temporary folder." =>
    "Chybí dočasný adresář.",

    "Failed to write file." =>
    "Soubor se nepodařilo se uložit.",

    "Denied file extension." =>
    "Nepodporovaný typ souboru.",

    "Unknown image format/encoding." =>
    "Neznámý formát obrázku/encoding.",

    "The image is too big and/or cannot be resized." =>
    "Obrázek je příliš velký/nebo nemohl být zmenšen.",

    "Cannot create {dir} folder." =>
    "Adresář {dir} nelze vytvořit.",

    "Cannot write to upload folder." =>
    "Nelze ukládat do adresáře pro nahrávání.",

    "Cannot read .htaccess" =>
    "Není možno číst soubor .htaccess",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "Chybný soubor .htaccess. Soubor nelze přepsat!",

    "Cannot read upload folder." =>
    "Nelze číst z adresáře pro nahrávání souborů.",

    "Cannot access or create thumbnails folder." =>
    "Adresář pro náhledy nelze vytvořit nebo není přístupný.",

    "Cannot access or write to upload folder." =>
    "Nelze přistoupit, nebo zapisovat do adresáře pro nahrávání souborů.",

    "Please enter new folder name." =>
    "Vložte prosím nové jméno adresáře.",

    "Unallowable characters in folder name." =>
    "Nepovolené znaky v názvu adresáře.",

    "Folder name shouldn't begins with '.'" =>
    "Jméno adresáře nesmí začínat znakem '.'",

    "Please enter new file name." =>
    "Vložte prosím nové jméno souboru.",

    "Unallowable characters in file name." =>
    "Nepovolené znaky v názvu souboru.",

    "File name shouldn't begins with '.'" =>
    "Název soubor nesmí začínat znakem '.'",

    "Are you sure you want to delete this file?" =>
    "Jste si jistý že chcete smazat tento soubor?",

    "Are you sure you want to delete this folder and all its content?" =>
    "Jste si jistý že chcete smazat tento adresář a celý jeho obsah?",

    "Inexistant or inaccessible folder." =>
    "Neexistující nebo nepřístupný adresář.",

    "Undefined MIME types." =>
    "Nedefinovaný MIME typ souboru.",

    "Fileinfo PECL extension is missing." =>
    "Rozříření PECL pro zjištění informací o souboru chybí.",

    "Opening fileinfo database failed." =>
    "Načtení informací o souboru selhalo.",

    "You can't upload such files." =>
    "Tyto soubory nemůžete nahrát na server.",

    "The file '{file}' does not exist." =>
    "Tento soubor '{file}' neexistuje.",

    "Cannot read '{file}'." =>
    "Nelze načíst '{file}'.",

    "Cannot copy '{file}'." =>
    "Nelze kopírovat '{file}'.",

    "Cannot move '{file}'." =>
    "Nelze přesunout '{file}'.",

    "Cannot delete '{file}'." =>
    "Nelze smazat '{file}'.",

    "Click to remove from the Clipboard" =>
    "Klikněte pro odstranění ze schránky",

    "This file is already added to the Clipboard." =>
    "Tento soubor je již ve schránce vložen.",

    "Copy files here" =>
    "Kopírovat soubory na toto místo",

    "Move files here" =>
    "Přesunout soubory na toto místo",

    "Delete files" =>
    "Smazat soubory",

    "Clear the Clipboard" =>
    "Vyčistit schránku",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "Jste si jistý že chcete vymazat všechny soubory ze schránky?",

    "Copy {count} files" =>
    "Kopírovat {count} souborů",

    "Move {count} files" =>
    "Přesunout {count} souborů",

    "Add to Clipboard" =>
    "Vložit do schránky",

    "New folder name:" => "Nový název adresáře:",
    "New file name:" => "Nový název souboru:",

    "Upload" => "Nahrát",
    "Refresh" => "Obnovit",
    "Settings" => "Nastavení",
    "Maximize" => "Maxializovat",
    "About" => "O aplikaci",
    "files" => "soubory",
    "View:" => "Zobrazit:",
    "Show:" => "Ukázat:",
    "Order by:" => "Řadit podle:",
    "Thumbnails" => "Náhledy",
    "List" => "Seznam",
    "Name" => "Jméno",
    "Size" => "Velikost",
    "Date" => "Datum",
    "Descending" => "Sestupně",
    "Uploading file..." => "Nahrávání souboru...",
    "Loading image..." => "Načítání obrázku...",
    "Loading folders..." => "Načítání adresářů...",
    "Loading files..." => "Načítání souborů...",
    "New Subfolder..." => "Nový adresář...",
    "Rename..." => "Přejmenovat...",
    "Delete" => "Smazat",
    "OK" => "OK",
    "Cancel" => "Zrušit",
    "Select" => "Vybrat",
    "Select Thumbnail" => "Vybrat náhled",
    "View" => "Zobrazit",
    "Download" => "Stažení",
    'Clipboard' => "Schránka",

    // VERSION 2 NEW LABELS

    "Cannot rename the folder." =>
    "Adresář nelze přejmenovat.",

    "Non-existing directory type." =>
    "Neexistující typ adresáře.",

    "Cannot delete the folder." =>
    "Adresář nelze smazat.",

    "The files in the Clipboard are not readable." =>
    "Soubory ve schránce nelze načíst.",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "{count} souborů ve schránce nelze načíst. Chcete zkopírovat zbylé soubory?",

    "The files in the Clipboard are not movable." =>
    "Soubory ve schránce nelze přesunout.",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "{count} souborů ve schránce nelze přesunout. Chcete přesunout zbylé soubory?",

    "The files in the Clipboard are not removable." =>
    "Soubory ve schránce nelze smazat.",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "{count} souborů ve schránce nelze smazat. Chcete smazat zbylé soubory?",

    "The selected files are not removable." =>
    "Označené soubory nelze smazat.",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "{count} označených souborů nelze smazat. Chcete smazat zbylé soubory?",

    "Are you sure you want to delete all selected files?" =>
    "Jste si jistý že chcete smazat vybrané soubory?",

    "Failed to delete {count} files/folders." =>
    "Nebylo smazáno {count} souborů/adresářů.",

    "A file or folder with that name already exists." =>
    "Soubor nebo adresář s takovým jménem již existuje.",

    "selected files" => "vybrané soubory",
    "Type" => "Typ",
    "Select Thumbnails" => "Vybrat náhled",
    "Download files" => "Stáhnout soubory",

    // SINCE 2.4

    "Checking for new version..." => "Zkontrolovat novou verzi...",
    "Unable to connect!" => "Nelze připojit!",
    "Download version {version} now!" => "Stáhnout verzi {version} nyní!",
    "KCFinder is up to date!" => "KCFinder je aktuální!",
    "Licenses:" => "Licence:",
    "Attention" => "Upozornění",
    "Question" => "Otázka",
    "Yes" => "Ano",
    "No" => "Ne",
);

?>