#!/usr/bin/env php
<?php
$command = false;

if (!empty($argv[1])) {
    $command = strtolower($argv[1]);
}

require 'vendor/autoload.php';

switch ($command) {
    case 'install':
        (new \CiextInstaller\Install())->run();
        break;
    case 'upgrade':
        (new \CiextInstaller\Upgrade())->run();
        break;
    default :
        echo 'Available commands: install, upgrade' . PHP_EOL;
        break;
}