<?php

/** Lithuanian localization file for KCFinder
  * author: Paulius Leščinskas <paulius.lescinskas@gmail.com>
  */

$lang = array(

    '_locale' => "lt_LT.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%F %T",
    '_dateTimeMid' => "%F %T",
    '_dateTimeSmall' => "%F %T",

	"You don't have permissions to upload files." =>
    "Jūs neturite teisių įkelti failus",

    "You don't have permissions to browse server." =>
    "Jūs neturite teisių naršyti po failus",

    "Cannot move uploaded file to target folder." =>
    "Nepavyko įkelti failo į reikiamą katalogą.",

    "Unknown error." =>
    "Nežinoma klaida.",

    "The uploaded file exceeds {size} bytes." =>
    "Įkeliamas failas viršija {size} baitų(-us).",

    "The uploaded file was only partially uploaded." =>
    "Failas buvo tik dalinai įkeltas.",

    "No file was uploaded." =>
    "Failas nebuvo įkeltas.",

    "Missing a temporary folder." =>
    "Nėra laikino katalogo.",

    "Failed to write file." =>
    "Nepavyko įrašyti failo.",

    "Denied file extension." =>
    "Draudžiama įkelti šio tipo failus.",

    "Unknown image format/encoding." =>
    "Nežinomas paveikslėlio formatas/kodavimas.",

    "The image is too big and/or cannot be resized." =>
    "Paveikslėlis yra per didelis ir/arba negali būti sumažintas.",

    "Cannot create {dir} folder." =>
    "Nepavyko sukurti {dir} katalogo.",

    "Cannot write to upload folder." =>
    "Nepavyko įrašyti į įkeliamų failų katalogą.",

    "Cannot read .htaccess" =>
    "Nepavyko nuskaityti .htaccess failo",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "Blogas .htaccess failas. Nepavyko jo perrašyti",

    "Cannot read upload folder." =>
    "Nepavyko atidaryti įkeliamų failų katalogo.",

    "Cannot access or create thumbnails folder." =>
    "Nepavyko atidaryti ar sukurti sumažintų paveikslėlių katalogo.",

    "Cannot access or write to upload folder." =>
    "Nepavyko atidaryti ar įrašyti į įkeliamų failų katalogą.",

    "Please enter new folder name." =>
    "Įveskite katalogo pavadinimą.",

    "Unallowable characters in folder name." =>
    "Katalogo pavadinime yra neleistinų simbolių.",

    "Folder name shouldn't begins with '.'" =>
    "Katalogo pavadinimas negali prasidėti '.'",

    "Please enter new file name." =>
    "Įveskite failo pavadinimą.",

    "Unallowable characters in file name." =>
    "Failo pavadinime yra neleistinų simbolių",

    "File name shouldn't begins with '.'" =>
    "Failo pavadinimas negali prasidėti '.'",

    "Are you sure you want to delete this file?" =>
    "Ar tikrai ištrinti šį failą?",

    "Are you sure you want to delete this folder and all its content?" =>
    "Ar tikrai ištrinti šį katalogą su visu jo turiniu?",

    "Inexistant or inaccessible folder." =>
    "Katalogas neegzistuoja arba yra neprieinamas.",

    "Undefined MIME types." =>
    "Nenurodytas MIME tipas.",

    "Fileinfo PECL extension is missing." =>
    "Trūksa PECL plėtinio Fileinfo",

    "Opening fileinfo database failed." =>
    "Nepavyko atidaryti Fileinfo duomenų bazės.",

    "You can't upload such files." =>
    "Negalima įkelti tokių failų.",

    "The file '{file}' does not exist." =>
    "Failas '{file}' neegzistuoja.",

    "Cannot read '{file}'." =>
    "Nepavyko atidaryti '{file}' failo.",

    "Cannot copy '{file}'." =>
    "Nepavyko nukopijuoti '{file}' failo.",

    "Cannot move '{file}'." =>
    "Nepavyko perkelti '{file}' failo.",

    "Cannot delete '{file}'." =>
    "Nepavyko ištrinti '{file}' failo.",

    "Click to remove from the Clipboard" =>
    "Zum entfernen aus der Zwischenablage, hier klicken.",

    "This file is already added to the Clipboard." =>
    "Šis failas jau įkeltas į laikinąją atmintį.",

    "Copy files here" =>
    "Kopijuoti failus čia.",

    "Move files here" =>
    "Perkelti failus čia.",

    "Delete files" =>
    "Ištrinti failus.",

    "Clear the Clipboard" =>
    "Išvalyti laikinąją atmintį",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "Ar tikrai ištrinti visus failus, esančius laikinojoje atmintyje?",

    "Copy {count} files" =>
    "Kopijuoti {count} failų(-us)",

    "Move {count} files" =>
    "Perkelti {count} failų(-us)",

    "Add to Clipboard" =>
    "Įkelti į laikinąją atmintį",

    "New folder name:" => "Naujo katalogo pavadinimas:",
    "New file name:" => "Naujo failo pavadinimas:",

    "Upload" => "Įkelti",
    "Refresh" => "Atnaujinti",
    "Settings" => "Nustatymai",
    "Maximize" => "Padidinti",
    "About" => "Apie",
    "files" => "Failai",
    "View:" => "Peržiūra:",
    "Show:" => "Rodyti:",
    "Order by:" => "Rikiuoti:",
    "Thumbnails" => "Sumažintos iliustracijos",
    "List" => "Sąrašas",
    "Name" => "Pavadinimas",
    "Size" => "Dydis",
    "Date" => "Data",
    "Descending" => "Mažejančia tvarka",
    "Uploading file..." => "Įkeliamas failas...",
    "Loading image..." => "Kraunami paveikslėliai...",
    "Loading folders..." => "Kraunami katalogai...",
    "Loading files..." => "Kraunami failai...",
    "New Subfolder..." => "Naujas katalogas...",
    "Rename..." => "Pervadinti...",
    "Delete" => "Ištrinti",
    "OK" => "OK",
    "Cancel" => "Atšaukti",
    "Select" => "Pažymėti",
    "Select Thumbnail" => "Pasirinkti sumažintą paveikslėlį",
    "View" => "Peržiūra",
    "Download" => "Atsisiųsti",
    'Clipboard' => "Laikinoji atmintis",

    // VERSION 2 NEW LABELS

    "Cannot rename the folder." =>
    "Nepavyko pervadinti katalogo.",

    "Non-existing directory type." =>
    "Neegzistuojantis katalogo tipas.",

    "Cannot delete the folder." =>
    "Nepavyko ištrinti katalogo.",

    "The files in the Clipboard are not readable." =>
    "Nepavyko nuskaityti failų iš laikinosios atminties.",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "Nepavyko atidaryti {count} failų(-ai) iš laikinosios atminties. Ar kopijuoti likusius?",

    "The files in the Clipboard are not movable." =>
    "Nepavyko perkelti failų iš laikinosios atminties.",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "Nepavyko perkelti {count} failų(-ai) iš laikinosios atminties. Ar perkelti likusius?",

    "The files in the Clipboard are not removable." =>
    "Nepavyko perkelti failų iš laikinosios atminties.",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "Nepavyko ištrinti {count} failų(-ai) iš laikinosios atminties. Ar ištrinti likusius?",

    "The selected files are not removable." =>
    "Nepavyko perkelti pažymėtų failų.",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "Nepavyko ištrinti {count} failų(-ai) iš laikinosios atminties. Ar ištrinti likusius?",

    "Are you sure you want to delete all selected files?" =>
    "Ar tikrai ištrinti visus pažymėtus failus?",

    "Failed to delete {count} files/folders." =>
    "Nepavyko ištrinti {count} failų/katalogų.",

    "A file or folder with that name already exists." =>
    "Failas arba katalogas tokiu pavadinimu jau egzistuoja.",

    "selected files" => "Pasirinkti failus",
    "Type" => "Tipas",
    "Select Thumbnails" => "Pasirinkti sumažintus paveikslėlius",
    "Download files" => "Atsisiųsti failus",
);

?>
