<?php

/** This file is part of KCFinder project
  *
  *      @desc Default English localization
  *   @package KCFinder
  *   @version 2.51
  *    @author Pavel Tzonkov <pavelc@users.sourceforge.net>
  * @copyright 2010 KCFinder Project
  *   @license http://www.opensource.org/licenses/gpl-2.0.php GPLv2
  *   @license http://www.opensource.org/licenses/lgpl-2.1.php LGPLv2
  *      @link http://kcfinder.sunhater.com
  */

$lang = array(
    '_locale' => "en_US.UTF-8",
    '_charset' => "utf-8",

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %B %e, %Y %I:%M %p",
    '_dateTimeMid' => "%a %b %e %Y %I:%M %p",
    '_dateTimeSmall' => "%m/%d/%Y %I:%M %p",
);

?>