/**
 * Localization strings for the UI Multiselect widget
 *
 * @locale en, en-US
 */

$.extend($.ui.multiselect.locale, {
	addAll:'Add all',
	removeAll:'Remove all',
	itemsCount:'items selected'
});
