<?php

/** Bulgarian localization file for KCFinder
  * author: Pavel Tzonkov <pavelc@users.sourceforge.net>
  */

$lang = array(

    '_locale' => "bg_BG.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %e %B, %Y %H:%M",
    '_dateTimeMid' => "%a %e %b %Y %H:%M",
    '_dateTimeSmall' => "%d.%m.%Y %H:%M",

    "You don't have permissions to upload files." =>
    "Нямате права за качване.",

    "You don't have permissions to browse server." =>
    "Нямате права за разглеждане на сървъра.",

    "Cannot move uploaded file to target folder." =>
    "Файлът не може да се премести в целевата папка.",

    "Unknown error." =>
    "Непозната грешка.",

    "The uploaded file exceeds {size} bytes." =>
    "Каченият файл надхвърля {size} байта.",

    "The uploaded file was only partially uploaded." =>
    "Каченият файл беше качен само частично.",

    "No file was uploaded." =>
    "Файлът не беше качен",

    "Missing a temporary folder." =>
    "Липсва временна папка.",

    "Failed to write file." =>
    "Грешка при записване на файла.",

    "Denied file extension." =>
    "Забранено файлово разширение.",

    "Unknown image format/encoding." =>
    "Файлът не може да бъде разпознат като изображение.",

    "The image is too big and/or cannot be resized." =>
    "Изображението е много голямо и/или не може да бъде преоразмерено.",

    "Cannot create {dir} folder." =>
    "Невъзможност да се създаде папка {dir}.",

    "Cannot rename the folder." =>
    "Папката не може да се преимеува.",

    "Cannot write to upload folder." =>
    "Не е възможно записването на файлове в папката за качване.",

    "Cannot read .htaccess" =>
    "Не е възможно прочитането на .htaccess",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "Невалиден .htaccess файл. Не може да се презапише автоматично!",

    "Cannot read upload folder." =>
    "Не е възможно прочитането на папката за качване.",

    "Cannot access or create thumbnails folder." =>
    "Невъзможен достъп или невъзможно създаване на папката за thumbnails.",

    "Cannot access or write to upload folder." =>
    "Папката не може да се достъпи или не може да се записва в нея.",

    "Please enter new folder name." =>
    "Моля въведете име на папката.",

    "Unallowable characters in folder name." =>
    "Непозволени знаци в името на папката.",

    "Folder name shouldn't begins with '.'" =>
    "Името на папката не трябва да започва с '.'",

    "Please enter new file name." =>
    "Моля въведете ново име на файла",

    "Unallowable characters in file name." =>
    "Непозволени знаци в името на файла.",

    "File name shouldn't begins with '.'" =>
    "Името на файла не трябва да започва с '.'",

    "Are you sure you want to delete this file?" =>
    "Наистина ли искате да изтриете този файл?",

    "Are you sure you want to delete this folder and all its content?" =>
    "Наистина ли искате да изтриете тази папка и цялото й съдържание?",

    "Non-existing directory type." =>
    "Несъществуващ специален тип на папка.",

    "Undefined MIME types." =>
    "Не са дефинирани MIME типове.",

    "Fileinfo PECL extension is missing." =>
    "Липсва Fileinfo PECL разширение.",

    "Opening fileinfo database failed." =>
    "Грешка при отваряне на fileinfo дефиниции.",

    "You can't upload such files." =>
    "Не можете да качвате такива файлове.",

    "The file '{file}' does not exist." =>
    "Фаълът '{file}' не съществува.",

    "Cannot read '{file}'." =>
    "Файлът '{file}' не може да бъде прочетен.",

    "Cannot copy '{file}'." =>
    "Файлът '{file}' не може да бъде копиран.",

    "Cannot move '{file}'." =>
    "Файлът '{file}' не може да бъде преместен.",

    "Cannot delete '{file}'." =>
    "Файлът '{file}' не може да бъде изтрит.",

    "Cannot delete the folder." =>
    "Папката не може да бъде изтрита.",

    "Click to remove from the Clipboard" =>
    "Цъкнете за да премахнете файла от клипборда",

    "This file is already added to the Clipboard." =>
    "Този файл вече е добавен към клипборда.",

    "The files in the Clipboard are not readable." =>
    "Файловете в клипборда не могат да се прочетат.",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "{count} файла в клипборда не могат да се прочетат. Искате ли да копирате останалите?",

    "The files in the Clipboard are not movable." =>
    "Файловете в клипборда не могат да бъдат преместени.",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "{count} файла в клипборда не могат да бъдат преместени. Искате ли да преместите останалите?",

    "The files in the Clipboard are not removable." =>
    "Файловете в клипборда не могат да бъдат изтрити.",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "{count} файла в клипборда не могат да бъдат изтрити. Искате ли да изтриете останалите?",

    "The selected files are not removable." =>
    "Избраните файлове не могат да бъдат изтрити.",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "{count} от избраните файлове не могат да бъдат изтрити. Искате ли да изтриете останалите?",

    "Are you sure you want to delete all selected files?" =>
    "Наистина ли искате да изтриете всички избрани файлове?",

    "Failed to delete {count} files/folders." =>
    "{count} файла/папки не могат да бъдат изтрити.",

    "A file or folder with that name already exists." =>
    "Вече има файл или папка с такова име.",

    "Copy files here" =>
    "Копирай файловете тук",

    "Move files here" =>
    "Премести файловете тук",

    "Delete files" =>
    "Изтрий файловете",

    "Clear the Clipboard" =>
    "Изчисти клипборда",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "Наистина ли искате да изтриете всички файлове от клипборда?",

    "Copy {count} files" =>
    "Копирай {count} файла",

    "Move {count} files" =>
    "Премести {count} файла",

    "Add to Clipboard" =>
    "Добави към клипборда",

    "Inexistant or inaccessible folder." =>
    "Несъществуваща или недостъпна папка.",

    "New folder name:" => "Име на папката:",
    "New file name:" => "Ново име на файла:",

    "Upload" => "Качи",
    "Refresh" => "Актуализирай",
    "Settings" => "Настройки",
    "Maximize" => "Разпъни",
    "About" => "Информация",
    "files" => "файла",
    "selected files" => "избрани файла",
    "View:" => "Изглед:",
    "Show:" => "Покажи:",
    "Order by:" => "Подреди по:",
    "Thumbnails" => "Картинки",
    "List" => "Списък",
    "Name" => "Име",
    "Type" => "Тип",
    "Size" => "Размер",
    "Date" => "Дата",
    "Descending" => "Обратен ред",
    "Uploading file..." => "Файлът се качва...",
    "Loading image..." => "Изображението се зарежда...",
    "Loading folders..." => "Зареждане на папките...",
    "Loading files..." => "Зареждане на папката...",
    "New Subfolder..." => "Нова подпапка...",
    "Rename..." => "Преименуване...",
    "Delete" => "Изтрий",
    "OK" => "OK",
    "Cancel" => "Отказ",
    "Select" => "Избери",
    "Select Thumbnail" => "Избери малък вариант",
    "Select Thumbnails" => "Избери малки варианти",
    "View" => "Преглед",
    "Download" => "Свали",
    "Download files" => "Свали файловете",
    "Clipboard" => "Клипборд",

    // SINCE 2.4

    "Checking for new version..." => "Проверка за нова версия...",
    "Unable to connect!" => "Не може да се свърже!",
    "Download version {version} now!" => "Свалете версия {version} сега!",
    "KCFinder is up to date!" => "KCFinder е актуален!",
    "Licenses:" => "Лицензи:",
    "Attention" => "Внимание",
    "Question" => "Въпрос",
    "Yes" => "Да",
    "No" => "Не",

    // SINCE 2.41

    "You cannot rename the extension of files!" =>
    "Не можете да преименувате разширенията на файловете!",

    // SINCE 2.5

    "Uploading file {number} of {count}... {progress}" =>
    "Качване на файл {number} от {count}... {progress}",

    "Failed to upload {filename}!" => "Несполучливо качване на {filename}!",
);

?>