.login{
    margin-bottom: 170px;
}
.login .logo{
    background: url("../img/logo.png") no-repeat;
    width: 104px;
    height: 64px;
    margin: 123px auto 115px;
}
.login form{
    width: 428px;
    margin: 0 auto;
}
.login input[type="text"], .login input[type="password"]{
    width: 414px;
    border-radius: 0;
}
.login label{
    font-size: 14px;
    margin-top: 27px;
    color: #7d7d7d;
}
.login button{
    margin-top: 2px;
    padding: 4px 30px;
    font-size: 13px;
}
