<?php

/** Chinese Simplified localization file for KCFinder
  * author: yutuo
  * country: China
  * E-mail: yutuo5@gmail.com
  * URL: yutuo.net
  */

$lang = array(

    '_locale' => "zh_CN.UTF-8",  // UNIX localization code
    '_charset' => "utf-8",       // Browser charset

    // Date time formats. See http://www.php.net/manual/en/function.strftime.php
    '_dateTimeFull' => "%A, %e %B, %Y %H:%M",
    '_dateTimeMid' => "%a %e %b %Y %H:%M",
    '_dateTimeSmall' => "%Y-%m-%d %H:%M",

    "You don't have permissions to upload files." =>
    "您没有权限上传文件。",

    "You don't have permissions to browse server." =>
    "您没有权限查看服务器文件。",

    "Cannot move uploaded file to target folder." =>
    "无法移动上传文件到指定文件夹。",

    "Unknown error." =>
    "发生不可预知异常。",

    "The uploaded file exceeds {size} bytes." =>
    "文件大小超过{size}字节。",

    "The uploaded file was only partially uploaded." =>
    "文件未完全上传。",

    "No file was uploaded." =>
    "文件未上传。",

    "Missing a temporary folder." =>
    "临时文件夹不存在。",

    "Failed to write file." =>
    "写入文件失败。",

    "Denied file extension." =>
    "禁止的文件扩展名。",

    "Unknown image format/encoding." =>
    "无法确认图片格式。",

    "The image is too big and/or cannot be resized." =>
    "图片大太，且（或）无法更改大小。",

    "Cannot create {dir} folder." =>
    "无法创建{dir}文件夹。",

    "Cannot write to upload folder." =>
    "无法写入上传文件夹。",

    "Cannot read .htaccess" =>
    "文件.htaccess无法读取。",

    "Incorrect .htaccess file. Cannot rewrite it!" =>
    "文件.htaccess错误，无法重写。",

    "Cannot read upload folder." =>
    "无法读取上传目录。",

    "Cannot access or create thumbnails folder." =>
    "无法访问或创建缩略图文件夹。",

    "Cannot access or write to upload folder." =>
    "无法访问或写入上传文件夹。",

    "Please enter new folder name." =>
    "请输入文件夹名。",

    "Unallowable characters in folder name." =>
    "文件夹名含有禁止字符。",

    "Folder name shouldn't begins with '.'" =>
    "文件夹名不能以点（.）为首字符。",

    "Please enter new file name." =>
    "请输入新文件名。",

    "Unallowable characters in file name." =>
    "文件名含有禁止字符。",

    "File name shouldn't begins with '.'" =>
    "文件名不能以点（.）为首字符。",

    "Are you sure you want to delete this file?" =>
    "是否确认删除该文件？",

    "Are you sure you want to delete this folder and all its content?" =>
    "是否确认删除该文件夹以及其子文件和子目录？",

    "Inexistant or inaccessible folder." =>
    "不存在或不可访问的文件夹。",

    "Undefined MIME types." =>
    "未定义的MIME类型。",

    "Fileinfo PECL extension is missing." =>
    "文件PECL属性不存在。",

    "Opening fileinfo database failed." =>
    "打开文件属性数据库出错。",

    "You can't upload such files." =>
    "你无法上传该文件。",

    "The file '{file}' does not exist." =>
    "文件{file}不存在。",

    "Cannot read '{file}'." =>
    "无法读取文件{file}。",

    "Cannot copy '{file}'." =>
    "无法复制文件{file}。",

    "Cannot move '{file}'." =>
    "无法移动文件{file}。",

    "Cannot delete '{file}'." =>
    "无法删除文件{file}。",

    "Click to remove from the Clipboard" =>
    "点击从剪贴板删除",

    "This file is already added to the Clipboard." =>
    "文件已复制到剪贴板。",

    "Copy files here" =>
    "复制到这里",

    "Move files here" =>
    "移动到这里",

    "Delete files" =>
    "删除这些文件",

    "Clear the Clipboard" =>
    "清除剪贴板",

    "Are you sure you want to delete all files in the Clipboard?" =>
    "是否确认删除所有在剪贴板的文件？",

    "Copy {count} files" =>
    "复制 {count} 个文件",

    "Move {count} files" =>
    "移动 {count} 个文件 ",

    "Add to Clipboard" =>
    "添加到剪贴板",

    "New folder name:" => "新文件夹名：",
    "New file name:" => "新文件夹：",

    "Upload" => "上传",
    "Refresh" => "刷新",
    "Settings" => "设置",
    "Maximize" => "最大化",
    "About" => "关于",
    "files" => "文件",
    "View:" => "视图：",
    "Show:" => "显示：",
    "Order by:" => "排序：",
    "Thumbnails" => "图标",
    "List" => "列表",
    "Name" => "文件名",
    "Size" => "大小",
    "Date" => "日期",
    "Descending" => "降序",
    "Uploading file..." => "正在上传文件...",
    "Loading image..." => "正在加载图片...",
    "Loading folders..." => "正在加载文件夹...",
    "Loading files..." => "正在加载文件...",
    "New Subfolder..." => "新建文件夹...",
    "Rename..." => "重命名...",
    "Delete" => "删除",
    "OK" => "OK",
    "Cancel" => "取消",
    "Select" => "选择",
    "Select Thumbnail" => "选择缩略图",
    "View" => "查看",
    "Download" => "下载",
    "Clipboard" => "剪贴板",

    // VERSION 2 NEW LABELS

    "Cannot rename the folder." =>
    "无法重命名该文件夹。",

    "Non-existing directory type." =>
    "不存在的目录类型。",

    "Cannot delete the folder." =>
    "无法删除该文件夹。",

    "The files in the Clipboard are not readable." =>
    "剪贴板上该文件无法读取。",

    "{count} files in the Clipboard are not readable. Do you want to copy the rest?" =>
    "剪贴板{count}个文件无法读取。 是否复制静态文件？",

    "The files in the Clipboard are not movable." =>
    "剪贴板上该文件无法移动。",

    "{count} files in the Clipboard are not movable. Do you want to move the rest?" =>
    "剪贴板{count}个文件无法移动。 是否移动静态文件？",

    "The files in the Clipboard are not removable." =>
    "剪贴板上该文件无法删除。",

    "{count} files in the Clipboard are not removable. Do you want to delete the rest?" =>
    "剪贴板{count}个文件无法删除。 是否删除静态文件？",

    "The selected files are not removable." =>
    "选中文件未删除。",

    "{count} selected files are not removable. Do you want to delete the rest?" =>
    "选中的{count}个文件未删除。是否删除静态文件？",

    "Are you sure you want to delete all selected files?" =>
    "是否确认删除选中文件？",

    "Failed to delete {count} files/folders." =>
    "{count}个文件或文件夹无法删除。",

    "A file or folder with that name already exists." =>
    "文件或文件夹已存在。",

    "selected files" => "选中的文件",
    "Type" => "种类",
    "Select Thumbnails" => "选择缩略图",
    "Download files" => "下载文件",
);

?>
